#
# spec file for package python-thLib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
Name:           python-thLib
Version:        0.12.2
Release:        5.16
Summary:        Collection of Python utilities for signal analysis
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            http://work.thaslwanter.at
Source:         https://files.pythonhosted.org/packages/source/t/thLib/thLib-%{version}.tar.gz
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module scikit-image}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module statsmodels}
BuildRequires:  %{python_module sympy}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib
Requires:       python-numpy
Requires:       python-pandas
Requires:       python-scikit-image
Requires:       python-scipy
Requires:       python-statsmodels
Requires:       python-sympy
BuildArch:      noarch
%python_subpackages

%description
The thLib package contains functions for working with sound, and for
fitting circles, lines, sine-waves, and exponential decays. For
signal processing, a Savitzky-Golay filter is included, as well as a
demonstration of the calculation of a power spectrum. UI utilities,
and a few useful vector functions (e.g. an implementation of the\
Savitzky-Golay algorithm) round off thLib.

Note: All functions for working with 3D kinematics have been moved into
the new package "scikit-kinematics"!

%prep
%setup -q -n thLib-%{version}
# hidden-file-or-dir
rm docs/_build/html/.buildinfo
# wrong-file-end-of-line-encoding
sed -i 's/\r$//' *.txt
sed -i 's/\r$//' docs/_build/html/_sources/*.txt
sed -i 's/\r$//' docs/_build/html/_static/pygments.css

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%{python_expand mkdir -p %{buildroot}%{_docdir}/%{$python_prefix}-thLib
cp -r docs/_build/html %{buildroot}%{_docdir}/%{$python_prefix}-thLib/
cp -r docs/_build/doctrees %{buildroot}%{_docdir}/%{$python_prefix}-thLib/
%fdupes %{buildroot}%{_docdir}/%{$python_prefix}-thLib/
}

%check
# no testsuite found

%files %{python_files}
%doc CHANGES.txt README.txt
%{_docdir}/%{python_prefix}-thLib/html/
%{_docdir}/%{python_prefix}-thLib/doctrees/
%{python_sitelib}/*

%changelog
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 (as that requires scipy)
* Fri Dec  6 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 support due to dependencies dropping python2.
* Thu Jun  6 2019 pgajdos@suse.com
- call spec-cleaner
- note there are no upstream tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May 16 2018 toddrme2178@gmail.com
- Update to version 0.12.2
  * quaternion export to "vector" added
  * quaternion export fixed for one-quaternion input
  * Equations for rot2Fick changed, so that they work for angles>pi
  * Fixed a problem for Gram-Schmidt orthogonalization with single vectors
  * Fixed a problem for for vector normalization in Python
    2.x, and one for quaternion division in Python 2.x
  * vel2quat made more stable, documentation adjusted
  * system identifier for Linux corrected; stereo sound enabled
  * sound information added
  * conversion command for FFMPEG adjusted, so that it also works on UNIX systems
  * Python 2.x compatability with Linux systems fixed
  * Problems with Sound.play() on POSIX-systems fixed
  * Kalman filter, Madgwick algorithm, Mahony algorith, getXSens added to thLib. Not thoroughly tested yet
  * Move all RST-files to the new folder "docs", and images to "_static"
  * Make it backwards-compatible to older installs of skimage
  * Clean up "quat"
  * Clean up "quat" a bit more
  * fixed error in "kinematics", cleaned the remaining modules up a bit
  * module "kinematics" replaced by "imus" and "markers", tests adjusted
  * fixed problems with relative imports
  * "quat2vel.py" added to "quats", docs and tests updated
  * fixed 2 errors in "imus.py"
  * "sound.py" made compatible with Linux
  * conversion problem in "sound.py" fixed
  * numerical error fixed
  * method for getting screen-width and -height added to ui
  * more info written out for JSON
  * Restore thLib, as older versions were inadvertently deleted :(
  * Code cleaned up a bit, comments for Mac added
  * quaternions and rotation matrices removed (to scikit-kinematics)
  * import error in sounds.py fixed
  * removed sound.py, because functionality exists in scikit-sound
- Implement single-spec version
* Tue Dec  9 2014 toddrme2178@gmail.com
- Initial version
